%%%%%%% K-means clustering %%%%%%%%
%
% Subject: This file is part of the Project RCP209 @ CNAM Paris, 
%          France - Summer 2010
%          This files uses K-means clustering to classify months as a function
%          of inflows, rainfall and snow.
% 
% To:  Michel CRUCIANU <Michel.Crucianu@cnam.fr>, 
%      Meziane YACOUB <meziane.yacoub@cnam.fr>
% 
% ----
% Franck DERNONCOURT <franck.dernoncourt@gmail.com>
% Phone: +33 601 188 949
% GTalk / Skype: franck.dernoncourt
% Address: 75013 Paris, France
% http://francky.me/
% http://www.linkedin.com/in/franckdernoncourt
% MATLAB : R2010a 64-bit (7.10.0.499)
% ----
%
% Data source: http://www.stats.uwo.ca/faculty/aim/epubs/mhsets/thompsto/
% Subject: 
% << 
% Prdiction  du dbit entrant d'un lac. L'objectif est de
% prdire l'volution du dbit entrant d'un lac  partir de
% l'historique de ce dbit, de la fonte des neiges et des prcipitations
% dans le bassin hydrographique.  Donnes :
% http://www.stats.uwo.ca/faculty/aim/epubs/mhsets/thompsto/
% Contact : Michel CRUCIANU <Michel.Crucianu@cnam.fr> 
% >>
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%% Data initialization %%
load inflows
load snow
load rainfall

%% Data standardization
% We want the transformed scores to have a mean of zero and a variance 
% (and standard deviation) of 1.
inflows = (inflows-mean(inflows)) ./ std(inflows);
rainfall = (rainfall-mean(rainfall)) ./ std(rainfall);
snow = (snow-mean(snow)) ./ std(snow);

% D is the data we want to classify
D = [inflows, rainfall, snow];
% D Normalization
for i = 1:length(D)
    normV = sqrt(D(i,1)^2 + D(i,2)^2 + D(i,3)^2 );
    D(i,1) = D(i,1) ./ normV;
    D(i,2) = D(i,2) ./ normV;
    D(i,3) = D(i,3) ./ normV;
end

%% Hierarchical clustering with clusterdata
% T = clusterdata(D,'maxclust',12);
T = clusterdata(D,'maxclust',12 , 'distance', 'mahalanobis', 'linkage','ward');
figure;
scatter3(D(:,1),D(:,2),D(:,3),50,T,'filled')
xlabel('inflow');
ylabel('rainfall');
zlabel('snow');


%% Kmeans clustering 
rmpath('Netlab'); % Netlab defines its own kmeans function, we want to use MATLAB's kmeans.
[idx,ctrs] = kmeans(D,4,'distance','city');


figure;
% hold on; %% !!! Be careful, if you place 'hold on' right after 'figure', then
%                 the figure will be in 2D
M = zeros(size(ctrs, 1), 1);
for i = 1:size(ctrs, 1)
    % plot3(D(idx==i,1),D(idx==i,2),D(idx==i,3), 'o', 'MarkerFaceColor',[i/size(ctrs, 1), 1-i/size(ctrs, 1), i/size(ctrs, 1)])
    s = size(ctrs, 1);
    red=250-5*max([0 i/s*100-50]);
    green=min([250 i/s*100*5]);
    blue = mod(i, 5)/5*175;
    plot3(D(idx==i,1),D(idx==i,2),D(idx==i,3), 'o', 'MarkerFaceColor',[red/255, green/255, blue/255], 'MarkerEdgeColor', [red/255, green/255, blue/255])
    hold on;
    pause(0.01);
end;
plot3(ctrs(:,1),ctrs(:,2),ctrs(:,3), 'kx',...
     'MarkerSize',12,'LineWidth',2)
plot3(ctrs(:,1),ctrs(:,2),ctrs(:,3),'ko',...
     'MarkerSize',12,'LineWidth',2)
% legend(M,'Centroids', 'Location','NW')
xlabel('inflow');
ylabel('rainfall');
zlabel('snow');
hold off

